@@ -43,8 +43,7 @@ def main(arguments=None):
     args=parser.parse_args(arguments)
 
     addDebugSystem(args.debug)
-
-
+    
     if args.remove==True:
             for language in ['es', 'en']:
                 remove_without_errors(f"unogenerator_documentation_{language}.odt")
@@ -217,6 +216,24 @@ def demo_ods_standard(language, port=2002, suffix="",):
     lod.append(OrderedDict({"Singer": "Elvis",  "Songs": 10000 , "Albums": 100}))
     lod.append(OrderedDict({"Singer": "Roy Orbison",  "Songs": 100,  "Albums": 20 }))
     helper_list_of_ordereddicts_with_totals(doc, "A36",  lod, columns_header=1)
+    
+    
+    doc.addColumnWithStyle("A41",  [1, 3, 2, 4, 1, 5])
+    doc.setColorScale("A41:A46")
+
+
+    ##Sort
+    doc.createSheet("Sort")
+    l=[7, 3, 2, 5, 6, 0, 9, 4, 10]
+    doc.addCellWithStyle("A1",  "Unsorted", ColorsNamed.Orange, "BoldCenter")
+    doc.addCellWithStyle("B1", "Sorted ASC", ColorsNamed.Orange, "BoldCenter")
+    doc.addCellWithStyle("C1", "Sorted DESC", ColorsNamed.Orange, "BoldCenter")
+    doc.addColumnWithStyle("A2", l)
+    doc.addColumnWithStyle("B2", l)
+    doc.addColumnWithStyle("C2", l)
+    doc.sortRange("B2:B10",  0)
+    doc.sortRange("C2:C10",  0, False)
+
 
     doc.save(f"unogenerator_example_{language}{suffix}.ods")
     doc.export_xlsx(f"unogenerator_example_{language}{suffix}.xlsx")
@@ -402,6 +419,15 @@ doc.close()"""    , "Code")
     
     
 #    doc.find_and_delete_until_the_end_of_document("This paragraph was set after replacement.")
+
+    doc.addParagraph(_("This is a pair of brackets ()."), "Standard")
+    doc.findall_and_replace(" ().", " )(.", True)
+    
+    doc.addParagraph(_("NOW)("), "Standard")
+    doc.addParagraph(_("This is a set of symbols: .,:;?ºª\_-/()."), "Standard")
+    doc.findall_and_replace(".,:;?ºª\_-/().", ".,:;?ºª\_-/(). REPLACED", True)
+    doc.addParagraph(_("NOW)("), "Standard")
+    
     
     
     doc.save(f"unogenerator_documentation_{language}{suffix}.odt")
